We Tried It: Clinique Acne Solutions Powder Makeup | YouBeauty
Author: http://www.youbeauty.com/authors/tiffanie-drayton
Description: A review of Clinique Acne Solutions Powder Makeup for dry, oily and combination skin.
Keywords: Clinique Acne Solutions Powder Makeup, dry skin, oily skin, face powder, combination skin,
Date: 2014-12-23T12:01:07-08:00

#### Follow Us

Facebook Pinterest

We're email friends!

If you'd like deeper access (taking quizzes, leaving comments) please register here.

# We Tried It: Clinique Acne Solutions Powder Makeup

## The powder immediately cut the shine and gave my skin an even, natural look.

By Tiffanie Drayton
| December 23rd, 2014

| 0 Comments

0
SHARES
Share Pin Tweet Email

I have confused skin. One moment it is dry and needs hydration and the next it is oily and greasy. So I need a powder that will cut the oil, but still let my skin breathe. Clinique Acne Solutions Powder Makeup gently covers blemishes, evens skin and even absorbs oil to leave skin looking fresh. It's made specifically for "dry combination to oily skin types," so it may be just what I have been looking for.

Product: Clinique Acne Solutions Powder Makeup

Price: $31.00

Tags:

How to Use it: The powder comes with a sponge applicator, but feel free to apply it with a powder brush as well. Apply to oily spots only or use the powder on your entire face for full-coverage. (It's also available in liquid form.)

Results: The shade that I received as a trial, Golden, was a bit too dark for my complexion, but I'm expecting to get a tan soon on a trip to the tropics. That aside, my skin has been in its oily phase for the past few days, so I was super excited to see if Clinique's Acne Solutions Powder Makeup really delivered — and it definitely did! The powder immediately cut the shine and gave my skin an even, natural look. It is very light and even thought it builds on your skin, it doesn't look or feel "caked on" like some powders do. I will be purchasing it for myself in the future, although maybe in a lighter shade.

Disclaimer: I received Clinique Acne Solutions Powder as a sample.

Related Articles:

Could Resveratrol Be the Secret to Clearer Skin?

Neroli Oil: The Ideal Face Oil for Oily Skin

5 Stubborn Skin Issues and How to Fix Them

Share Pin Tweet Email
Tags: Clinique, Powder, We Tried It, Beauty, Makeup, Face
Print
Save
Smart is sexy - get our newsletter:

Let's be friends!
Pinterest
Follow

#### Join the Conversation

Stories We Love

#### Comments on this Article (0) | Leave a Comment

Loading…

3. Reason*
4. Explanation

Sexual Satisfaction Quiz

#### How's Your Sex Life?

Great sex does more than blow your mind—it's good for your heart, your head and your beauty.

Take Quiz
Let's hang out
Pinterest
Follow

Most Popular

- ###### Should Women Receive Paid Menstrual Leave?

- ###### Why You Shouldn't Ignore Vitamin D, The "Sunshine Vitamin"

- ###### Alyssa Milano Asks Why Her Breastfeeding Selfie Got More Hate Than Kim’s Butt Pics

- ###### 8 Exercises to Get Rid of Back Fat

- ###### What Is Leaky Gut Syndrome?

X

###### Be Your Most Beautiful You

Highlight your eye color. Flaunt your body shape. Harness your confidence. Take our quizzes to better know yourself and get science-based, individualized advice to embrace your true beauty.

- ##### Sexual Satisfaction Quiz

  #### How's Your Sex Life?

  Great sex does more than blow your mind—it's good for your heart, your head and your beauty.

  Take Quiz

- #### Sleep Quality Quiz

  #### Do You Get Enough Quality Sleep?

  Good sleepers are beautiful, happier and enjoy better sex. Learn how to be better rested.

  Take Quiz

- #### Healthy Hair Quiz

  #### There Are 16 Factors That Determine Your Hair Type

  Learn why your hair does what it does, and get styling and product tips to make it do what you want.

  Take Quiz

- #### Eye Makeup Quiz

  #### Play Up Your Peepers

  If shopping for eye makeup is one big guessing game, find your best colors here.

  Take Quiz
- See all 33 quizzes

<< Close

## Sign In or Sign Up

### Join the YouBeauty community! Start discussions, share your advice and comment on stories. Save articles you love to your MyBeauty Dashboard for anytime access (you can track your discussions there, too). Plus, take any of our quizzes for personal beauty and wellness advice.

1. Email Address*

Do you have a YouBeauty password?

No, I am new to YouBeauty
Yes, my password is:

Forgot your password?

I sign in to YouBeauty by connecting my Facebook, Google Plus, Twitter, Yahoo, or AOL account.
CONTACT US

#### Need Advice?

Our experts and readers can help you—post your questions in YouTalk.

Do you have feedback, questions or concerns about YouBeauty? Send us an email using this form, or a letter at the below address.

YouBeauty.com
185 Madison Avenue
Floor 5
New York, NY 10016

* Fields marked with an asterisk are required

1. *I am writing to:*
2. *Email Address:*
3. *First Name:*
4. *Last Name:*
5. *Your Message:*
6. *What is 0 + 3*
Spell out the answer, for example 5 + 2 = seven